#!/bin/sh

if [ $# -lt 1 ]
then
	echo "Usage: makeweb.sh <directories>"
	exit 1
fi

outIndex="list.html"
targetFormat="eps"
thumbFormat="jpg"
bigFormat="png"
descFormat="txt"
webFormat="html"


rm $outIndex
cat > $outIndex << EOF
<html>
<head><title>US Road Signs</title></head>
<body bgcolor="ffFFff">
<h1>US Road Signs</h1>
EOF

while [ $# -gt 0 ]
do
	dir=$1
	shift
	echo "----------------- Processing Directory $dir -----------------"
	
	cat >> $outIndex <<EOF
<h3>$dir</h3>
<table>
<tr>
EOF
	cols="0"
	
	for target in `cd $dir; echo ??-*.$targetFormat ???-*.$targetFormat ??[^-][^-]*.$targetFormat`
	do
		echo "$target" | grep '?'  && continue
		base=`echo $target | sed -e "s/\.$targetFormat//"`
		web="$base.$webFormat"
		thumb="$base.$thumbFormat"
		big="$base.$bigFormat"
		desc="$base.$descFormat"
		name="$base"
		[ -r $dir/$desc ] && name=`grep "Name" $dir/$desc | awk -F: '{print $2}'`
		cat > $dir/$web <<EOF
<html>
<head><title>US Road Signs: $name ($dir)</title></head>
<body bgcolor="ffFFff">
<h1>Signs: $name ($dir)</h1>
EOF
		if [ -r $dir/$desc ]
		then
			echo "<pre>" >> $dir/$web
			cat $dir/$desc >> $dir/$web
			echo "</pre><br>" >> $dir/$web
		fi
		cat >> $dir/$web <<EOF
<p>Download: Original <a href="$target">EPS</a>, big <a href="$big">PNG</a>, 
or tiny <a href="$thumb">JPG</a>.
<p><img src="$big" alt="Road Sign: $name">
<hr>
Back to Orion's <a href="../index.html">US Road Signs</a>.<br>
Back to Orion's <a href="../../../../index.html">Home Page</a>.<br>
<a href="mailto:olawlor@acm.org">Orion Sky Lawlor</a>, January 2003<br>
</html>
EOF
		
		cat >> $outIndex <<EOF
<td><a href="$dir/$web"><img src="$dir/$thumb" alt="$name"></a></td>
EOF
		
		cols=`expr $cols + 1`
		if [ $cols -ge 9 ] 
		then
			cols="0"
			cat >> $outIndex <<EOF

</tr><tr>

EOF
		fi
	done
	cat >> $outIndex <<EOF
</tr>
</table>
<br>
EOF
done

cat >> $outIndex <<EOF
<p>
<hr>
Back to <a href="index.html">Main sign and download page</a>.<br>
Back to Orion's <a href="../../../index.html">Home Page</a>.<br>
<a href="mailto:olawlor@acm.org">Orion Sky Lawlor</a>, January 2003<br>
</html>
EOF

echo "makeweb.sh done"
